Specializations
===============

The following implementation of the above archetypes are available as part of this repository. The planned implementations are marked as TODO.

Mappers
-------

* DictionaryMapper
* [TODO] R2RmlMapper
* [TODO] TableMapper


Mappings
--------

* DictionaryMapping

Models
------

* DemoModel
* RdfModel: currently supports `SHACL <https://www.w3.org/TR/shacl/>`__ shapes.

Resolvers
---------

* DemoResolver
* OntologyResolver
* AgentResolver

Stores
------

* DemoStore: a in-memory Store (do not use it in production)
* `BlueBrainNexus <https://github.com/BlueBrain/nexus>`__
